==> distribution-5.52.1.zip: drr/standards/iosco/cde/reports/CDEPriceScheduleAmountFormatPercentageRule.java <==
package drr.standards.iosco.cde.reports;

import com.google.inject.ImplementedBy;
import com.rosetta.model.lib.expression.CardinalityOperator;
import com.rosetta.model.lib.mapper.MapperS;
import com.rosetta.model.lib.reports.ReportFunction;
import drr.regulation.common.PriceReportablePeriod;
import drr.regulation.common.functions.FormatToBaseOneRate;
import drr.regulation.common.functions.MultiplyPrice;
import drr.regulation.esma.emir.refit.trade.PriceAndNotation;
import drr.standards.iso.PriceNotationEnum;
import java.math.BigDecimal;
import javax.inject.Inject;

import static com.rosetta.model.lib.expression.ExpressionOperators.*;

@ImplementedBy(CDEPriceScheduleAmountFormatPercentageRule.CDEPriceScheduleAmountFormatPercentageRuleDefault.class)
public abstract class CDEPriceScheduleAmountFormatPercentageRule implements ReportFunction<PriceReportablePeriod, BigDecimal> {
	
	// RosettaFunction dependencies
	//
	@Inject protected FormatToBaseOneRate formatToBaseOneRate;
	@Inject protected MultiplyPrice multiplyPrice;

	/**
	* @param input 
	* @return output 
	*/
	@Override
	public BigDecimal evaluate(PriceReportablePeriod input) {
		BigDecimal output = doEvaluate(input);
		
		return output;
	}

	protected abstract BigDecimal doEvaluate(PriceReportablePeriod input);

	public static class CDEPriceScheduleAmountFormatPercentageRuleDefault extends CDEPriceScheduleAmountFormatPercentageRule {
		@Override
		protected BigDecimal doEvaluate(PriceReportablePeriod input) {
			BigDecimal output = null;
			return assignOutput(output, input);
		}
		
		protected BigDecimal assignOutput(BigDecimal output, PriceReportablePeriod input) {
			final MapperS<PriceAndNotation> thenArg = MapperS.of(input)
				.mapSingleToItem(item -> item.<PriceAndNotation>map("getPeriodValue", priceReportablePeriod -> priceReportablePeriod.getPeriodValue()));
			final MapperS<BigDecimal> ifThenElseResult;
			if (areEqual(thenArg.<PriceNotationEnum>map("getPriceNotation", priceAndNotation -> priceAndNotation.getPriceNotation()), MapperS.of(PriceNotationEnum.PERCENTAGE), CardinalityOperator.All).getOrDefault(false)) {
				ifThenElseResult = MapperS.of(multiplyPrice.evaluate(thenArg.<BigDecimal>map("getPricePercentage", priceAndNotation -> priceAndNotation.getPricePercentage()).get(), thenArg.<PriceNotationEnum>map("getPriceNotation", priceAndNotation -> priceAndNotation.getPriceNotation()).get()));
			} else {
				ifThenElseResult = MapperS.<BigDecimal>ofNull();
			}
			output = MapperS.of(formatToBaseOneRate.evaluate(ifThenElseResult.get())).get();
			
			return output;
		}
	}
}

==> distribution-5.55.0.zip: drr/standards/iosco/cde/reports/CDEPriceScheduleAmountFormatPercentageRule.java <==
package drr.standards.iosco.cde.reports;

import com.google.inject.ImplementedBy;
import com.rosetta.model.lib.expression.CardinalityOperator;
import com.rosetta.model.lib.mapper.MapperS;
import com.rosetta.model.lib.reports.ReportFunction;
import drr.regulation.common.PriceReportablePeriod;
import drr.regulation.common.functions.FormatToBaseOneRate;
import drr.regulation.common.functions.MultiplyPrice;
import drr.regulation.esma.emir.refit.trade.PriceAndNotation;
import drr.standards.iso.PriceNotationEnum;
import java.math.BigDecimal;
import javax.inject.Inject;

import static com.rosetta.model.lib.expression.ExpressionOperatorsNullSafe.*;

@ImplementedBy(CDEPriceScheduleAmountFormatPercentageRule.CDEPriceScheduleAmountFormatPercentageRuleDefault.class)
public abstract class CDEPriceScheduleAmountFormatPercentageRule implements ReportFunction<PriceReportablePeriod, BigDecimal> {
	
	// RosettaFunction dependencies
	//
	@Inject protected FormatToBaseOneRate formatToBaseOneRate;
	@Inject protected MultiplyPrice multiplyPrice;

	/**
	* @param input 
	* @return output 
	*/
	@Override
	public BigDecimal evaluate(PriceReportablePeriod input) {
		BigDecimal output = doEvaluate(input);
		
		return output;
	}

	protected abstract BigDecimal doEvaluate(PriceReportablePeriod input);

	public static class CDEPriceScheduleAmountFormatPercentageRuleDefault extends CDEPriceScheduleAmountFormatPercentageRule {
		@Override
		protected BigDecimal doEvaluate(PriceReportablePeriod input) {
			BigDecimal output = null;
			return assignOutput(output, input);
		}
		
		protected BigDecimal assignOutput(BigDecimal output, PriceReportablePeriod input) {
			final MapperS<PriceAndNotation> thenArg = MapperS.of(input)
				.mapSingleToItem(item -> item.<PriceAndNotation>map("getPeriodValue", priceReportablePeriod -> priceReportablePeriod.getPeriodValue()));
			final MapperS<BigDecimal> ifThenElseResult;
			if (areEqual(thenArg.<PriceNotationEnum>map("getPriceNotation", priceAndNotation -> priceAndNotation.getPriceNotation()), MapperS.of(PriceNotationEnum.PERCENTAGE), CardinalityOperator.All).getOrDefault(false)) {
				ifThenElseResult = MapperS.of(multiplyPrice.evaluate(thenArg.<BigDecimal>map("getPricePercentage", priceAndNotation -> priceAndNotation.getPricePercentage()).get(), thenArg.<PriceNotationEnum>map("getPriceNotation", priceAndNotation -> priceAndNotation.getPriceNotation()).get()));
			} else {
				ifThenElseResult = MapperS.<BigDecimal>ofNull();
			}
			output = MapperS.of(formatToBaseOneRate.evaluate(ifThenElseResult.get())).get();
			
			return output;
		}
	}
}
